# Increase when packaging a newer snapshot
%define mainrel 12
%define date    20170428
# Increase when rebuilding the same snapshot
%define snaprel 1

Name:           ioquake3
Version:        1.36
%define subrel 1
Release:        %mkrel %{mainrel}.%{date}.%{snaprel}
Summary:        Quake 3 Arena engine (ioquake3 version)
Group:          Games/Shooter
License:        GPLv2+
URL:            http://ioquake3.org/
# Snapshot from git repository: https://github.com/ioquake/ioq3
# - Strip thirdparty code:
# rm -rf code/{AL,jpeg-8c,libcurl-*,libogg-*,libspeex,libvorbis-*,opus-*,opusfile-*,SDL2,zlib}
# - Strip nonfree code (lcc) and binaries:
# rm -rf code/libs code/tools/lcc
Source0:        %{name}-%{date}.tar.xz
Source1:        %{name}-demo.sh
Source2:        %{name}.autodlrc
Source3:        %{name}.desktop
Source4:        %{name}.png
Source5:        %{name}-update.sh
Source6:        %{name}-update.autodlrc
Patch0: 	ioquake-1.36-CVE-2017-11721-buffer-overflow.patch

BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(zlib)
%ifarch %{ix86} x86_64
BuildRequires:  nasm
%endif

# for quake3-update
Requires:       autodownloader 

%description
This package contains the enhanced opensource ioquake3 version of the Quake 3
Arena engine. This engine can be used to play a number of games based on this
engine, below is an (incomplete list):

* OpenArena, Free, Open Source Quake3 like game, recommended!
  (packagename: openarena)

* Urban Terror, gratis, but not Open Source FPS best be described as a
  Hollywood tactical shooter, a downloader and installer including an
  application menu entry is available in the urbanterror package.

* World of Padman, gratis, but not Open Source Comic FPS, a downloader and
  installer including an application menu entry is available in the
  worldofpadman package.

* Smokin' Guns, gratis, but not Open Source FPS, a semi-realistic simulation of 
  the "Old West's" great atmosphere, a downloader and installer including an
  application menu entry is available in the smokinguns package.

* Quake3 Arena, the original! A downloader and installer for the gratis, but
  not Open Source demo, including an application menu entry is available in
  the quake3-demo package.
  
  If you own a copy of quake 3, you will need to copy pak0.pk3 from the
  original CD-ROM and your q3key to %{_libexecdir}/quake3/baseq3 or ~/.q3a/baseq3.
  Also copy the pak?.pk3 files from the original 1.32 Quake 3 Arena point
  release there if you have them available or run quake3-update to download
  them for you.


%package demo
Summary:        Quake 3 Arena tournament 3D shooter game demo installer
Group:          Games/Shooter
Requires:       ioquake3 = %{version}-%{release}
Requires:       opengl-games-utils 
BuildArch:      noarch

%description demo
Quake 3 Arena tournament 3D shooter game demo installer. The Quake3 engine is
Open Source and as such is available as part of Mageia. The original Quake3
data files however are not Open Source and thus are not available as part of
Mageia. There is a gratis, but not Open Source demo available on the internet.

This package installs an application menu entry for playing the Quake3 Arena
demo. The first time you click this menu entry, it will offer to download and
install the Quake 3 demo datafiles for you.


%prep
%autosetup -p1 -n %{name}-%{date}

%build
%make_build \
  BUILD_CLIENT_SMP=1 \
  BUILD_GAME_SO=1 \
  BUILD_GAME_QVM=0 \
  DEFAULT_BASEDIR=%{_libexecdir}/%{name} \
  GENERATE_DEPENDENCIES=0 \
  OPTIMIZE="%{optflags}" \
  USE_CODEC_VORBIS=1 \
  USE_CODEC_OPUS=1 \
  USE_CURL=1 \
  USE_CURL_DLOPEN=0 \
  USE_INTERNAL_LIBS=0 \
  USE_LOCAL_HEADERS=0 \
  USE_OPENAL=1 \
  USE_OPENAL_DLOPEN=0 \
  VERSION="\\\"%{version} (git %{date}) [%{_vendor} %{release}]\\\""


%install
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_datadir}/%{name}
install -d %{buildroot}%{_libexecdir}/%{name}/{baseq3,missionpack}

# ioquake3 binaries
pushd build/release-linux-*
install -m 755 %{name}.* %{buildroot}%{_bindir}/%{name}
install -m 755 ioq3ded.* %{buildroot}%{_bindir}/ioq3ded

install -m 755 renderer_opengl*.so %{buildroot}%{_libexecdir}/%{name}/
install -m 755 baseq3/*.so %{buildroot}%{_libexecdir}/%{name}/baseq3/
install -m 755 missionpack/*.so %{buildroot}%{_libexecdir}/%{name}/missionpack/
popd

# script to download the demo
install -m 755 %{SOURCE1} %{buildroot}%{_bindir}/ioquake3-demo
install -m 644 %{SOURCE2} %{buildroot}%{_datadir}/%{name}/

# script to install the latest patch
install -m 755 %{SOURCE5} %{buildroot}%{_bindir}/ioquake3-update
install -m 644 %{SOURCE6} %{buildroot}%{_datadir}/%{name}/

# desktop file and icons
install -D -m 644 misc/setup/%{name}.desktop \
  %{buildroot}%{_datadir}/applications/%{name}.desktop
install -D -m 644 misc/quake3.svg \
  %{buildroot}%{_iconsdir}/hicolor/scalable/apps/quake3.svg
install -D -m 644 misc/quake3.png \
  %{buildroot}%{_iconsdir}/hicolor/32x32/apps/quake3.png

%files
%doc md4-readme.txt opengl2-readme.md README.md voip-readme.txt
%license COPYING.txt id-readme.txt
%{_bindir}/%{name}
%{_bindir}/%{name}-update
%{_bindir}/ioq3ded
%{_datadir}/%{name}/%{name}-update.autodlrc
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/32x32/apps/quake3.png
%{_iconsdir}/hicolor/scalable/apps/quake3.svg
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/baseq3/
%{_libexecdir}/%{name}/missionpack/
%{_libexecdir}/%{name}/renderer_opengl*.so

%files demo
%{_bindir}/%{name}-demo
%{_datadir}/%{name}/%{name}.autodlrc


%changelog
* Sat Jan 13 2018 mrambo3501 <mrambo3501> 1.36-12.20170428.1.1.mga6
+ Revision: 1192668
- added debian patch which fixes CVE-2017-11721 mga#21580

* Tue May 09 2017 akien <akien> 1.36-12.20170428.1.mga6
+ Revision: 1099843
- Git snapshot 20170428
  o Upstreams P2 and P3, also drop P1 and P4 which are Debian-specific
  o Fixes a crtical security vulnerability:
    https://ioquake3.org/2017/03/13/important-security-update-please-update-ioquake3-immediately/
- Build the game .so libraries, and put them in /usr/libexec/quake3
  o The .pk3 will now also be expected there, or in ~/.q3a as usual
- Now builds against SDL2 and Opus, removes Speex
- Cleanup build options, define meaningful version string

* Mon Feb 15 2016 umeabot <umeabot> 1.36-11.svn2102.5.mga6
+ Revision: 960693
- Mageia 6 Mass Rebuild

* Thu Oct 29 2015 tv <tv> 1.36-11.svn2102.4.mga6
+ Revision: 896519
- BR pkgconfig(speexdsp)

* Wed Oct 15 2014 umeabot <umeabot> 1.36-11.svn2102.3.mga5
+ Revision: 744275
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.36-11.svn2102.2.mga5
+ Revision: 680531
- Mageia 5 Mass Rebuild

* Sun Jun 22 2014 wally <wally> 1.36-11.svn2102.1.mga5
+ Revision: 638658
- rebuild for mga5

* Wed Jan 09 2013 malo <malo> 1.36-11.svn2102.mga3
+ Revision: 343797
- updated RPM group

* Fri Nov 16 2012 juancho <juancho> 1.36-10.svn2102.mga3
+ Revision: 318404
- Change group to new Games/Shooter

* Fri Mar 02 2012 juancho <juancho> 1.36-9.svn2102.mga2
+ Revision: 216696
- Removed Suggests for urbanterror, quake3-demo and worldofpadman

* Thu Dec 08 2011 juancho <juancho> 1.36-8.svn2102.mga2
+ Revision: 178837
- Added Smokin' Guns to the description.
- Removed unneeded patch

* Wed Dec 07 2011 juancho <juancho> 1.36-7.svn2102.mga2
+ Revision: 178420
- Fixed group for ioquake3-demo
- Added missing BuildRequires: desktop-file-utils
- Fixed group
- Replaced current spec with latest from Fedora (quake3-1.36-12.svn2102.fc17) and adapted it for Mageia to be used with other ioquake3 based games.
- Replaced current spec with latest from Fedora (quake3-1.36-12.svn2102.fc17) and adapted it for Mageia to be used with other ioquake3 based games.

* Sun Apr 17 2011 stormi <stormi> 1.36-6.mga1
+ Revision: 87417
- fix RPM group

* Thu Apr 14 2011 pterjan <pterjan> 1.36-5.mga1
+ Revision: 84816
- Re-upload after upload bug

* Wed Apr 13 2011 juancho <juancho> 1.36-4.mga1
+ Revision: 84716
- Fixed format of some lines, fixed group tags, removed BuildRoot and removed remaining Authors: lines

* Wed Apr 13 2011 tv <tv> 1.36-3.mga1
+ Revision: 84650
- description != authors file

* Wed Apr 13 2011 juancho <juancho> 1.36-2.mga1
+ Revision: 84450
- imported package ioquake3


* Fri Dec 10 2010 Oden Eriksson <oeriksson@mandriva.com> 1.36-2mdv2011.0
+ Revision: 619674
- the mass rebuild of 2010.0 packages

* Mon Sep 28 2009 Juan Luis Baptiste <juancho@mandriva.org> 1.36-1mdv2010.0
+ Revision: 450586
- Patch to fix compilation issue from 1.36
- Added back TOOLS_OPTIMIZE to make options and patched code to make it compile with -Werror=format-security
- Removed a forgotten debug print message.
- Updated to 1.36.
  Removed TOOLS_OPTIMIZE from make options as expanded flags from %%{optflags} break compilation.

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Fri Dec 05 2008 Zombie Ryushu <ryushu@mandriva.org> 1.35-0.1486.1mdv2009.1
+ Revision: 310695
- Fix Invalid Group
- Fix License Tags
- Fix OpenAL BuildRequires
- import ioquake3

  + Buchan Milne <bgmilne@mandriva.org>
    - Fix snapshot versioning
    - Buildrequire openal-devel


* Mon Nov 10 2008 lnussel@suse.de
- update to SVN1486 in trunk
* Wed Nov  5 2008 lnussel@suse.de
- update to SVN1481 in trunk
* Fri Sep 12 2008 lnussel@suse.de
- update to SVN1470 in trunk
* Wed Sep  3 2008 lnussel@suse.de
- update to SVN1469 in trunk
* Wed Aug 20 2008 lnussel@suse.de
- update to SVN1450 in trunk
* Sat Aug  9 2008 lnussel@suse.de
- update to SVN 1443 in trunk
* Thu Jul 17 2008 lnussel@suse.de
- update to SVN 1429 in trunk
* Wed Jul 16 2008 lnussel@suse.de
- update to SVN 1427 in trunk
* Sun Jul  6 2008 lnussel@suse.de
- update to SVN 1419 in trunk
* Sun Jul  6 2008 lnussel@suse.de
- update to SVN 1413 in trunk
* Sat Jul  5 2008 lnussel@suse.de
- update to SVN 1403 in trunk
* Wed Jun 25 2008 lnussel@suse.de
- update to SVN 1398 in trunk
* Wed Jun 25 2008 lnussel@suse.de
- update to SVN 1394 in trunk
* Sun Jun  8 2008 lnussel@suse.de
- update to SVN 1382 in trunk
  * now support voice activation for voip
* Sat Jun  7 2008 lnussel@suse.de
- update to SVN 1371 in trunk
- use upstream desktop file
* Thu Jun  5 2008 lnussel@suse.de
- update to SVN 1369 in trunk
* Tue Jun  3 2008 lnussel@suse.de
- update to SVN 1363 in trunk
- includes voip support
* Sat May 31 2008 lnussel@suse.de
- update to SVN 1347 in trunk
- use dlopen for libopenal in installer build
* Wed May  7 2008 lnussel@suse.de
- update to SVN 1341 in trunk
* Sat May  3 2008 lnussel@suse.de
- update to SVN 1337 in trunk
* Mon Apr 28 2008 lnussel@suse.de
- update to SVN 1332 in trunk
  * supports stereoscopic view
* Tue Apr 22 2008 lnussel@suse.de
- update to SVN 1324 in trunk
* Tue Apr 15 2008 lnussel@suse.de
- update to SVN 1321 in trunk
* Sat Apr 12 2008 lnussel@suse.de
- update to SVN 1318 in trunk
* Thu Apr 10 2008 lnussel@suse.de
- update to SVN 1307 in trunk
* Mon Apr  7 2008 lnussel@suse.de
- update to SVN 1303 in trunk
* Sun Apr  6 2008 lnussel@suse.de
- update to SVN 1300 in trunk
* Sat Apr  5 2008 lnussel@suse.de
- update to SVN 1294 in trunk
* Sat Apr  5 2008 lnussel@suse.de
- update to SVN 1290 in trunk
  * initial ipv6 support
* Fri Mar 28 2008 lnussel@suse.de
- update to SVN 1287 in trunk
* Thu Mar 27 2008 lnussel@suse.de
- update to SVN 1286 in trunk
* Fri Mar 21 2008 lnussel@suse.de
- update to SVN 1272 in trunk
* Sun Mar  9 2008 lnussel@suse.de
- update to SVN 1270 in trunk
* Wed Jan 23 2008 lnussel@suse.de
- update to SVN 1250 in trunk
  * fixes several format string bugs
* Wed Jan  9 2008 lnussel@suse.de
- update to SVN 1248 in trunk
* Sat Dec  8 2007 lnussel@suse.de
- update to SVN 1231 in trunk
* Fri Nov 16 2007 lnussel@suse.de
- update to SVN 1212 in trunk
* Tue Oct 23 2007 lnussel@suse.de
- update to SVN 1201 in trunk
* Fri Oct  5 2007 lnussel@suse.de
- update to SVN 1189 in trunk
* Tue Sep 11 2007 lnussel@suse.de
- update to SVN 1176 in trunk
* Thu Sep  6 2007 lnussel@suse.de
- update to SVN 1166 in trunk
* Mon Aug 27 2007 lnussel@suse.de
- update to SVN 1138 in trunk
* Sun Aug 19 2007 lnussel@suse.de
- update to SVN 1126 in trunk
* Wed Jul  4 2007 lnussel@suse.de
- update to SVN 1106 in trunk
- update vm_x86_64 assembler patch
* Fri Jun 29 2007 lnussel@suse.de
- update to SVN 1103 in trunk
- add experimental vm_x86_64 assembler patch
* Fri May 11 2007 lnussel@suse.de
- update to SVN 1083 in trunk
* Tue Jan 23 2007 lnussel@suse.de
- update to SVN 1036 in trunk
- rename to ioquake3
* Fri Dec  1 2006 lnussel@suse.de
- update to SVN 996 in 1.34 branch (1.34RC3)
* Thu Oct 26 2006 lnussel@suse.de
- update to SVN 955 in 1.34 branch
  * fixes wrong use of strncat
- disable installer
* Tue Sep  5 2006 lnussel@suse.de
- update to SVN 892 (1.34RC2)
* Mon Jun  5 2006 lnussel@suse.de
- update to SVN 797
  * fixes buffer overflow in CL_ParseDownload
  * fixes ppc vm
* Mon May  8 2006 lnussel@suse.de
- update to SVN 777
  * fixes directory traversal bug (CVE-2006-2082)
* Sat May  6 2006 lnussel@suse.de
- update to SVN 772
  * fixes exploitable buffer overflow (CVE-2006-2236)
* Thu Mar  9 2006 lnussel@suse.de
- update to current SVN
  * fixes among other things SEGV on i386 without READ_IMPLIES_EXEC
* Tue Feb 21 2006 lnussel@suse.de
- update to current SVN
- add desktop file and start script
* Mon Jan 30 2006 ro@suse.de
- added Mesa-devel to BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 lnussel@suse.de
- update to current SVN
  * offending EULA removed (#136922)
* Thu Dec  1 2005 lnussel@suse.de
- update to current SVN
  * quake3-setup subpackage builds installer for upstream
* Mon Nov 14 2005 lnussel@suse.de
- update to current SVN
  * with openal support
* Thu Nov  3 2005 lnussel@suse.de
- update to current SVN
* Sun Oct  9 2005 lnussel@suse.de
- update to current SVN
- add devel subpackage that contains qvm compiler and assembler
* Fri Sep  9 2005 lnussel@suse.de
- update to current SVN
  * supposed to fix soundlag
  * works on 16bit displays
* Thu Sep  1 2005 lnussel@suse.de
- update to current SVN, now with SDL sound
* Wed Aug 31 2005 lnussel@suse.de
- new package
